StreamEventPayload

Enum StreamEventPayload 

pub enum StreamEventPayload {
    MessageStart {
        message: Value,
    },
    ContentBlockStart {
        index: u64,
        content_block: ContentBlockInfo,
    },
    ContentBlockDelta {
        index: u64,
        delta: Delta,
    },
    ContentBlockStop {
        index: u64,
    },
    MessageDelta {
        delta: Value,
        usage: Option<Value>,
    },
    MessageStop,
    Unknown,
}
The inner event payload from the Anthropic streaming API.

This mirrors the Server-Sent Events that the Anthropic API emits.

Variants



MessageStart

Signals the start of a new message, includes message metadata.

Fields

message: Value

The message object with id, role, model, etc.



ContentBlockStart

Signals the start of a content block at the given index.

Fields

index: u64

Zero-based index of this content block.

content_block: ContentBlockInfo

The initial content block (type, and any initial data).



ContentBlockDelta

An incremental update to the content block at the given index.

Fields

index: u64

Zero-based index of the content block being updated.

delta: Delta

The delta payload.



ContentBlockStop

Signals that the content block at the given index is complete.

Fields

index: u64

Zero-based index of the completed content block.



MessageDelta

An update to the top-level message (e.g. stop_reason, usage).

Fields

delta: Value

The delta payload.

usage: Option<Value>

Updated usage statistics.



MessageStop

Signals that the entire message is complete.



Unknown

Catch-all for forward-compatibility with unknown event types.