pub enum StreamEventPayload {
MessageStart {
message: Value,
},
ContentBlockStart {
index: u64,
content_block: ContentBlockInfo,
},
ContentBlockDelta {
index: u64,
delta: Delta,
},
ContentBlockStop {
index: u64,
},
MessageDelta {
delta: Value,
usage: Option<Value>,
},
MessageStop,
Unknown,
}Expand description
The inner event payload from the Anthropic streaming API.
This mirrors the Server-Sent Events that the Anthropic API emits.
Variants
MessageStart
Signals the start of a new message, includes message metadata.
ContentBlockStart
Signals the start of a content block at the given index.
Fields

content_block: ContentBlockInfoThe initial content block (type, and any initial data).
ContentBlockDelta
An incremental update to the content block at the given index.
Fields
ContentBlockStop
Signals that the content block at the given index is complete.
MessageDelta
An update to the top-level message (e.g. stop_reason, usage).
MessageStop
Signals that the entire message is complete.
Unknown
Catch-all for forward-compatibility with unknown event types.